@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use base 'Perl::Tidy::Sweetened';
 
-our $VERSION = '1.14';
+our $VERSION = '1.15';
 
 1;
 
@@ -20,7 +20,7 @@ Perl::Tidy::Sweet - Tweaks to Perl::Tidy to support some syntactic sugar
 
 =head1 VERSION
 
-version 1.14
+version 1.15
 
 =head1 STATUS
 
@@ -72,32 +72,6 @@ L<Perl::Tidy>
 
 Mark Grimes E<lt>mgrimes@cpan.orgE<gt>
 
-=head1 CONTRIBUTORS
-
-=over 4
-
-=item *
-
-Kent Fredric (@kentnl)
-
-=item *
-
-Gregoy Oschwald (@oschwal)
-
-=item *
-
-Curtis Brandt (@aggrolite)
-
-=item *
-
-@pblaberge
-
-=item *
-
-Peter Roberts (@pwr22)
-
-=back
-
 =head1 SOURCE
 
 Source repository is at L<https://github.com/mvgrimes/Perl-Tidy-Sweetened>.
